@@ -8,8 +8,9 @@ describe 'cinder::wsgi::apache' do
         :bind_port                   => 8776,
         :group                       => 'cinder',
         :path                        => '/',
+        :priority                    => 10,
         :servername                  => facts[:fqdn],
-        :ssl                         => true,
+        :ssl                         => false,
         :threads                     => 1,
         :user                        => 'cinder',
         :workers                     => facts[:os_workers],
@@ -18,30 +19,34 @@ describe 'cinder::wsgi::apache' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'cinder-api',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
+        :headers                     => nil,
+        :request_headers             => nil,
         :custom_wsgi_process_options => {},
-        :access_log_file             => false,
-        :access_log_pipe             => false,
-        :access_log_syslog           => false,
-        :access_log_format           => false,
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
         :error_log_file              => nil,
         :error_log_pipe              => nil,
         :error_log_syslog            => nil,
       )}
     end
 
-    context'when overriding parameters using different ports' do
+    context 'when overriding parameters' do
       let :params do
         {
           :servername                  => 'dummy.host',
           :bind_host                   => '10.42.51.1',
           :port                        => 12345,
-          :ssl                         => false,
+          :ssl                         => true,
           :vhost_custom_fragment       => 'Timeout 99',
           :wsgi_process_display_name   => 'cinder-api',
           :workers                     => 37,
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/admin/path',
           },
+          :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+          :request_headers             => ['set Content-Type "application/json"'],
         }
       end
       it { is_expected.to contain_class('cinder::params') }
@@ -51,7 +56,7 @@ describe 'cinder::wsgi::apache' do
         :group                     => 'cinder',
         :path                      => '/',
         :servername                => 'dummy.host',
-        :ssl                       => false,
+        :ssl                       => true,
         :threads                   => 1,
         :user                      => 'cinder',
         :vhost_custom_fragment     => 'Timeout 99',
@@ -62,6 +67,8 @@ describe 'cinder::wsgi::apache' do
         :wsgi_script_dir           => platform_params[:wsgi_script_path],
         :wsgi_script_file          => 'cinder-api',
         :wsgi_script_source        => platform_params[:wsgi_script_source],
+        :headers                   => ['set X-XSS-Protection "1; mode=block"'],
+        :request_headers           => ['set Content-Type "application/json"'],
         :custom_wsgi_process_options => {
           'python_path'  => '/my/python/admin/path',
         },
